@@ -1,5 +1,5 @@
 package Catalyst::Controller::ActionRole;
-our $VERSION = '0.04_01';
+our $VERSION = '0.01';
 
 # ABSTRACT: Apply roles to action instances
 
@@ -14,6 +14,17 @@ use namespace::clean -except => 'meta';
 
 extends 'Catalyst::Controller';
 
+if ($Catalyst::VERSION < 5.8 && !__PACKAGE__->isa('Moose::Object')) {
+    unshift our @ISA, 'Moose::Object';
+
+    around new => sub {
+        my $next = shift;
+        my ($self, $app) = @_;
+        my $arguments = ( ref( $_[-1] ) eq 'HASH' ) ? $_[-1] : {};
+        return $self->$next( $self->merge_config_hashes($self->config, $arguments) );
+    };
+}
+
 
 __PACKAGE__->mk_classdata(qw/_action_role_prefix/);
 __PACKAGE__->_action_role_prefix('Catalyst::Action::Role::');
@@ -26,9 +37,6 @@ has _action_roles => (
     auto_deref => 1,
 );
 
-# FIXME: this isn't what BUILDARGS was intended for. I guess the expansion
-# should be done in a trigger.
-
 override BUILDARGS => sub {
     my ($self) = @_;
     my $args = super;
@@ -44,7 +52,7 @@ sub create_action {
     my ($self, %args) = @_;
 
     my $class = exists $args{attributes}->{ActionClass}
-        ? $args{attributes}->{ActionClass}->[0]
+        ? $args{attributes}->{ActionClass}
         : $self->_action_class;
 
     Class::MOP::load_class($class);
@@ -90,7 +98,7 @@ Catalyst::Controller::ActionRole - Apply roles to action instances
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
